Ref NeaReaderGSF_test

Scan: |  | Fourier Scan
Project: |  | Spectroscopy datasets
Description: |  | Ref NeaReaderGSF_test
Date: |  | 02/02/2020 00:22:00
Scanner Center Position (X, Y): | [µm] | 65.31 | 42.72 |
Rotation: | [°] | 0 |  |
Scan Area (X, Y, Z): | [µm] | 0.000 | 0.000 | 0.000
Pixel Area (X, Y, Z): | [px] | 1 | 1 | 1024
Interferometer Center/Distance: | [µm] | 700.000 | 1,000.000 |
Averaging: |  | 1 |  |
Integration time: | [ms] | 15 |  |
Laser Source: |  | Synchrotron
Target Wavelength: | [µm] |  |  |
Demodulation Mode: |  | Fourier
Tip Frequency: | [Hz] | 243,743.824 |  |
Tip Amplitude: | [mV] | 14.600 |  |
Tapping Amplitude: | [nm] | 81.504 |  |
Modulation Frequency: | [Hz] | 0.000 |  |
Modulation Amplitude: | [mV] | 0.000 |  |
Modulation Offset: | [mV] | 0.000 |  |
Setpoint: | [%] | 76.19 |  |
Regulator (P, I, D): |  | 3.507821 | 9.892523 | 1.000000
Tip Potential: | [mV] | 0.000 |  |
M1A Scaling: | [nm/V] | 4.978 |  |
Version: |  | 1.8.4702.0